.. _in_playground:

Arbor Playground
================

You can try Arbor in the browser right now! Navigate to `arbor-sim.org/playground <https://arbor-sim.org/playground>`_.

This is an Emscripten + Pyodide port of Arbor and is meant to be a simple showcase of neural modelling in Arbor.
If you want to do serious work with it, we recommend installing Arbor GUI for a graphical interface to Arbor or the
library itself. While Arbor is a stable, robust simulator designed to run large-scale simulations on thousands of CPU/GPU
nodes, the Playground port comes with some limitations. Notable, only single CPU simulations are supported.
Long-running simulations may freeze the user interface. Please report any issues on GitHub. 
